@@ -440,7 +440,7 @@ def _row(t, func, size):
 
 
 @check_pen
-def row(t, func, size, anim=False):
+def row(t, func, size=10, anim=False):
     if anim:
         _flashrow(t, func, size)
     else:
